@@ -11,9 +11,12 @@ from .load_data import load_data, loaddata
 from .load_signal import load_signal, loadsig
 from .plot_complex import plotc, plot_complex
 from .plot_3d_complex import plot_3d_complex, plot3c
+from .save_bits import save_bits, savebits
+from .save_data import save_data, savedata
 from .save_signal import save_signal, savesig
 from .signal_correlation import sigcorr, signal_correlation
 from .signal_types import FullSignalType
 from .truncation import true_one, true_zero
 from .root_raised_cosine_filter_generator import root_raised_cosine_filter_generator, rrcfiltgen
 from .root_raised_cosine import root_raised_cosine, rrcfunct
+from .generate_qam import generate_qam
